# Muck Snake

A tribute to a friend who passed away - he built this game to make others happy.

## Installation

With an existing python installation it's as simple as: 
```
pip install mucksnake
mucksnake
```

## Authors and acknowledgment

Aaron Muckleroy is the original author of this package.  Minor additions have been made to make sure this work can be shared easily with others who might want to occasionally play a game of snake and remember how it felt when Aaron would ask - "How are you doing?" and listen.  He was always ready to hear how you were REALLY feeling, and ready to help in any way he could.
